pspp-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Pspp-cvs] Changes to pspp/src/som.h


From: John Darrington
Subject: [Pspp-cvs] Changes to pspp/src/som.h
Date: Thu, 13 Jan 2005 23:05:53 -0500

Index: pspp/src/som.h
diff -u pspp/src/som.h:1.1 pspp/src/som.h:1.2
--- pspp/src/som.h:1.1  Wed Dec 10 23:34:48 2003
+++ pspp/src/som.h      Fri Jan 14 04:05:47 2005
@@ -36,11 +36,18 @@
    desired, and in fact almost every operation performed by som may be
    overridden in a table class.  */
 
-/* Table. */
-struct som_table
+enum som_type
+  {
+    SOM_TABLE,
+    SOM_CHART
+  } ;
+
+/* Entity (Table or Chart) . */
+struct som_entity
   {
     struct som_table_class *class;     /* Table class. */
-    void *ext;                         /* Owned by table class. */
+    enum som_type type;                 /* Table or Chart */ 
+    void *ext;                         /* Owned by */
   };
 
 /* Group styles. */
@@ -70,7 +77,7 @@
 struct som_table_class
   {
     /* Set table, driver. */
-    void (*table) (struct som_table *);
+    void (*table) (struct som_entity *);
     void (*driver) (struct outp_driver *);
 
     /* Query columns and rows. */
@@ -100,7 +107,7 @@
 
 /* Submission. */
 void som_new_series (void);
-void som_submit (struct som_table *t);
+void som_submit (struct som_entity *t);
 
 /* Miscellaneous. */
 void som_eject_page (void);




reply via email to

[Prev in Thread] Current Thread [Next in Thread]